@@ -316,6 +316,89 @@ get_generic (GdMainView *self)
   return NULL;
 }
 
+static void
+selection_mode_do_select_range (GdMainView *self,
+                                GtkTreeIter *first_element,
+                                GtkTreeIter *last_element)
+{
+  GtkTreeIter iter;
+  GtkTreePath *path, *last_path;
+  gboolean equal;
+
+  last_path = gtk_tree_model_get_path (self->priv->model, last_element);
+  iter = *first_element;
+
+  do
+    {
+      gtk_list_store_set (GTK_LIST_STORE (self->priv->model), &iter,
+                          GD_MAIN_COLUMN_SELECTED, TRUE,
+                          -1);
+
+      path = gtk_tree_model_get_path (self->priv->model, &iter);
+      equal = (gtk_tree_path_compare (path, last_path) == 0);
+      gtk_tree_path_free (path);
+
+      if (equal)
+        break;
+    }
+  while (gtk_tree_model_iter_next (self->priv->model, &iter));
+
+  gtk_tree_path_free (last_path);
+}
+
+static void
+selection_mode_select_range (GdMainView *self,
+                             GtkTreeIter *iter)
+{
+  GtkTreeIter other;
+  gboolean found = FALSE;
+  gboolean selected;
+
+  other = *iter;
+  while (gtk_tree_model_iter_previous (self->priv->model, &other))
+    {
+      gtk_tree_model_get (self->priv->model, &other,
+                          GD_MAIN_COLUMN_SELECTED, &selected,
+                          -1);
+
+      if (selected)
+        {
+          found = TRUE;
+          break;
+        }
+    }
+
+  if (found)
+    {
+      selection_mode_do_select_range (self, &other, iter);
+      return;
+    }
+
+  other = *iter;
+  while (gtk_tree_model_iter_next (self->priv->model, &other))
+    {
+      gtk_tree_model_get (self->priv->model, &other,
+                          GD_MAIN_COLUMN_SELECTED, &selected,
+                          -1);
+      if (selected)
+        {
+          found = TRUE;
+          break;
+        }
+    }
+
+  if (found)
+    {
+      selection_mode_do_select_range (self, iter, &other);
+      return;
+    }
+
+  /* no other selected element found, just select the iter */
+  gtk_list_store_set (GTK_LIST_STORE (self->priv->model), iter,
+                      GD_MAIN_COLUMN_SELECTED, TRUE,
+                      -1);
+}
+
 static gboolean
 on_button_release_selection_mode (GdMainView *self,
                                   GdkEventButton *event,
@@ -333,13 +416,20 @@ on_button_release_selection_mode (GdMainView *self,
                       -1);
 
   if (selected && !entered_mode)
-    gtk_list_store_set (GTK_LIST_STORE (self->priv->model), &iter,
-                        GD_MAIN_COLUMN_SELECTED, FALSE,
-                        -1);
+    {
+      gtk_list_store_set (GTK_LIST_STORE (self->priv->model), &iter,
+                          GD_MAIN_COLUMN_SELECTED, FALSE,
+                          -1);
+    }
   else if (!selected)
-    gtk_list_store_set (GTK_LIST_STORE (self->priv->model), &iter,
-                        GD_MAIN_COLUMN_SELECTED, TRUE,
-                        -1);
+    {
+      if ((event->state & GDK_SHIFT_MASK) == 0)
+        gtk_list_store_set (GTK_LIST_STORE (self->priv->model), &iter,
+                            GD_MAIN_COLUMN_SELECTED, TRUE,
+                            -1);
+      else
+        selection_mode_select_range (self, &iter);
+    }
 
   g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
 
@@ -533,19 +623,6 @@ gd_main_view_apply_model (GdMainView *self)
   gd_main_view_generic_set_model (generic, self->priv->model);
 }
 
-static gboolean
-clear_selection_list_foreach (GtkTreeModel *model,
-                              GtkTreePath *path,
-                              GtkTreeIter *iter,
-                              gpointer user_data)
-{
-  gtk_list_store_set (GTK_LIST_STORE (model), iter,
-                      GD_MAIN_COLUMN_SELECTED, FALSE,
-                      -1);
-
-  return FALSE;
-}
-
 static void
 gd_main_view_apply_selection_mode (GdMainView *self)
 {
@@ -555,12 +632,7 @@ gd_main_view_apply_selection_mode (GdMainView *self)
 
   if (!self->priv->selection_mode &&
       self->priv->model != NULL)
-    {
-      gtk_tree_model_foreach (self->priv->model,
-                              clear_selection_list_foreach,
-                              self);
-      g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
-    }
+    gd_main_view_unselect_all (self);
 }
 
 static void
@@ -723,3 +795,40 @@ gd_main_view_get_selection (GdMainView *self)
 
   return g_list_reverse (retval);
 }
+
+static gboolean
+set_selection_foreach (GtkTreeModel *model,
+                       GtkTreePath *path,
+                       GtkTreeIter *iter,
+                       gpointer user_data)
+{
+  gboolean selection = GPOINTER_TO_INT (user_data);
+
+  gtk_list_store_set (GTK_LIST_STORE (model), iter,
+                      GD_MAIN_COLUMN_SELECTED, selection,
+                      -1);
+
+  return FALSE;
+}
+
+void
+gd_main_view_select_all (GdMainView *self)
+{
+  gboolean selection = TRUE;
+
+  gtk_tree_model_foreach (self->priv->model,
+                          set_selection_foreach,
+                          GINT_TO_POINTER (selection));
+  g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
+}
+
+void
+gd_main_view_unselect_all (GdMainView *self)
+{
+  gboolean selection = FALSE;
+
+  gtk_tree_model_foreach (self->priv->model,
+                          set_selection_foreach,
+                          GINT_TO_POINTER (selection));
+  g_signal_emit (self, signals[VIEW_SELECTION_CHANGED], 0);
+}
