@@ -158,7 +158,11 @@ const Application = new Lang.Class({
             { name: 'rotate-left', accel: '<Primary>Left',
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'rotate-right', accel: '<Primary>Right',
-              window_mode: WindowMode.WindowMode.PREVIEW }
+              window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'select-all', accel: '<Primary>a',
+              window_mode: WindowMode.WindowMode.OVERVIEW },
+            { name: 'select-none',
+              window_mode: WindowMode.WindowMode.OVERVIEW }
         ];
 
         actionEntries.forEach(Lang.bind(this,
@@ -261,13 +265,17 @@ const Application = new Lang.Class({
         Global.modeController = new WindowMode.ModeController();
         Global.notificationManager = new Notifications.NotificationManager();
 
-        // startup a refresh of the gdocs cache
-        let gdataMiner = new Miners.GDataMiner();
-        this._refreshMinerNow(gdataMiner);
+        try {
+          // startup a refresh of the gdocs cache
+          let gdataMiner = new Miners.GDataMiner();
+          this._refreshMinerNow(gdataMiner);
 
-        // startup a refresh of the skydrive cache
-        let zpjMiner = new Miners.ZpjMiner();
-        this._refreshMinerNow(zpjMiner);
+          // startup a refresh of the skydrive cache
+          let zpjMiner = new Miners.ZpjMiner();
+          this._refreshMinerNow(zpjMiner);
+        } catch (e) {
+	  log('Unable to start miners: ' + e.message);
+        }
 
         this._initActions();
         this._initAppMenu();
