@@ -25,6 +25,7 @@ const Tweener = imports.util.tweener;
 
 const Global = imports.global;
 const MainToolbar = imports.mainToolbar;
+const Notifications = imports.notifications;
 const Preview = imports.preview;
 const Searchbar = imports.searchbar;
 const Selections = imports.selections;
@@ -33,6 +34,7 @@ const WindowMode = imports.windowMode;
 
 const Clutter = imports.gi.Clutter;
 const EvView = imports.gi.EvinceView;
+const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
@@ -56,7 +58,11 @@ const SpinnerBox = new Lang.Class({
                                      valign: Gtk.Align.CENTER });
 
         this.actor = new GtkClutter.Actor({ contents: this.widget,
-                                            opacity: 255 });
+                                            opacity: 255,
+                                            x_align: Clutter.ActorAlign.FILL,
+                                            x_expand: true,
+                                            y_align: Clutter.ActorAlign.FILL,
+                                            y_expand: true });
 
         this._spinner = new Gtk.Spinner({ width_request: _ICON_SIZE,
                                           height_request: _ICON_SIZE,
@@ -84,7 +90,9 @@ const SpinnerBox = new Lang.Class({
 
     moveIn: function() {
         this._clearDelayId();
-        this.actor.raise_top();
+
+        let parent = this.actor.get_parent();
+        parent.set_child_above_sibling(this.actor, null);
 
         Tweener.addTween(this.actor, { opacity: 255,
                                        time: 0.30,
@@ -98,7 +106,8 @@ const SpinnerBox = new Lang.Class({
                                        time: 0.30,
                                        transition: 'easeOutQuad',
                                        onComplete: function () {
-                                           this.actor.lower_bottom();
+                                           let parent = this.actor.get_parent();
+                                           parent.set_child_below_sibling(this.actor, null);
                                        },
                                        onCompleteScope: this });
     },
@@ -151,7 +160,11 @@ const ErrorBox = new Lang.Class({
         this.widget.show_all();
 
         this.actor = new GtkClutter.Actor({ contents: this.widget,
-                                            opacity: 255 });
+                                            opacity: 255,
+                                            x_align: Clutter.ActorAlign.FILL,
+                                            x_expand: true,
+                                            y_align: Clutter.ActorAlign.FILL,
+                                            y_expand: true });
     },
 
     update: function(primary, secondary) {
@@ -163,7 +176,8 @@ const ErrorBox = new Lang.Class({
     },
 
     moveIn: function() {
-        this.actor.raise_top();
+        let parent = this.actor.get_parent();
+        parent.set_child_above_sibling(this.actor, null);
 
         Tweener.addTween(this.actor, { opacity: 255,
                                        time: 0.30,
@@ -175,17 +189,95 @@ const ErrorBox = new Lang.Class({
                                        time: 0.30,
                                        transition: 'easeOutQuad',
                                        onComplete: function () {
-                                           this.actor.lower_bottom();
+                                           let parent = this.actor.get_parent();
+                                           parent.set_child_below_sibling(this.actor, null);
                                        },
                                        onCompleteScope: this });
     }
 });
 
+const EmptyResultsBox = new Lang.Class({
+    Name: 'EmptyResultsBox',
+
+    _init: function() {
+        this.widget = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
+                                     column_spacing: 12,
+                                     hexpand: true,
+                                     vexpand: true,
+                                     halign: Gtk.Align.CENTER,
+                                     valign: Gtk.Align.CENTER });
+        this.widget.get_style_context().add_class('dim-label');
+
+        this._image = new Gtk.Image({ pixel_size: 64,
+                                      icon_name: 'emblem-documents-symbolic' });
+        this.widget.add(this._image);
+
+        this._labelsGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
+                                          row_spacing: 12 });
+        this.widget.add(this._labelsGrid);
+
+        let titleLabel = new Gtk.Label({ label: '<b><span size="large">' +
+                                         _("No Documents Found") +
+                                         '</span></b>',
+                                         use_markup: true,
+                                         halign: Gtk.Align.START,
+                                         vexpand: true });
+        this._labelsGrid.add(titleLabel);
+
+        if (Global.sourceManager.hasOnlineSources()) {
+            titleLabel.valign = Gtk.Align.CENTER;
+        } else {
+            titleLabel.valign = Gtk.Align.START;
+            this._addSystemSettingsLabel();
+        }
+
+        this.actor = new GtkClutter.Actor({ contents: this.widget,
+                                            opacity: 255 });
+        this.widget.show_all();
+    },
+
+    _addSystemSettingsLabel: function() {
+        let details = new Gtk.Label({ label: _("You can add your online accounts in") +
+                                      " <a href=\"system-settings\">" + _("System Settings") + "</a>",
+                                      use_markup: true,
+                                      halign: Gtk.Align.START,
+                                      xalign: 0,
+                                      max_width_chars: 24,
+                                      wrap: true });
+        this._labelsGrid.add(details);
+
+        details.connect('activate-link', Lang.bind(this,
+            function(label, uri) {
+                if (uri != 'system-settings')
+                    return false;
+
+                try {
+                    let app = Gio.AppInfo.create_from_commandline(
+                        'gnome-control-center online-accounts', null, 0);
+
+                    let screen = this.widget.get_screen();
+                    let display = screen ? screen.get_display() : Gdk.Display.get_default();
+                    let ctx = display.get_app_launch_context();
+
+                    if (screen)
+                        ctx.set_screen(screen);
+
+                    app.launch([], ctx);
+                } catch(e) {
+                    log('Unable to launch gnome-control-center: ' + e.message);
+                }
+
+                return true;
+            }));
+    }
+});
+
 const Embed = new Lang.Class({
     Name: 'Embed',
 
     _init: function() {
         this._queryErrorId = 0;
+        this._noResultsChangeId = 0;
 
         this.widget = new GtkClutter.Embed({ use_layout_size: true });
         this.widget.show();
@@ -215,26 +307,34 @@ const Embed = new Lang.Class({
         this._notebook = new Gtk.Notebook({ show_tabs: false,
                                             show_border: false });
         this._notebook.show();
-        this._notebookActor = new GtkClutter.Actor({ contents: this._notebook });
-        this._viewLayout.add(this._notebookActor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
+        this._notebookActor = new GtkClutter.Actor({ contents: this._notebook,
+                                                     x_align: Clutter.ActorAlign.FILL,
+                                                     x_expand: true,
+                                                     y_align: Clutter.ActorAlign.FILL,
+                                                     y_expand: true });
+        this._viewActor.add_child(this._notebookActor);
 
         this._spinnerBox = new SpinnerBox();
-        this._viewLayout.add(this._spinnerBox.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
-        this._spinnerBox.actor.lower_bottom();
+        this._viewActor.insert_child_below(this._spinnerBox.actor, null);
 
         this._errorBox = new ErrorBox();
-        this._viewLayout.add(this._errorBox.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
-        this._errorBox.actor.lower_bottom();
+        this._viewActor.insert_child_below(this._errorBox.actor,  null);
+
+        this._noResults = new EmptyResultsBox();
+        this._viewLayout.add(this._noResults.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
+        this._noResults.actor.lower_bottom();
 
         // also pack a white background to use for spotlights between window modes
         this._background =
             new Clutter.Rectangle({ color: new Clutter.Color ({ red: 255,
                                                                 blue: 255,
                                                                 green: 255,
-                                                                alpha: 255 }) });
-        this._viewLayout.add(this._background,
-            Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
-        this._background.lower_bottom();
+                                                                alpha: 255 }),
+                                    x_align: Clutter.ActorAlign.FILL,
+                                    x_expand: true,
+                                    y_align: Clutter.ActorAlign.FILL,
+                                    y_expand: true });
+        this._viewActor.insert_child_below(this._background, null);
 
         // create the OSD toolbar for selected items, it's hidden by default
         this._selectionToolbar = new Selections.SelectionToolbar(this._contentsActor);
@@ -242,8 +342,10 @@ const Embed = new Lang.Class({
             Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
 
         // pack the OSD notification actor
-        this._viewLayout.add(Global.notificationManager.actor,
-            Clutter.BinAlignment.CENTER, Clutter.BinAlignment.START);
+        this._viewActor.add_child(Global.notificationManager.actor);
+
+        // start the monitor for the indexing notification
+        this._indexingNotification = new Notifications.IndexingNotification();
 
         // now create the actual content widgets
         this._view = new View.ViewContainer();
@@ -261,6 +363,9 @@ const Embed = new Lang.Class({
         Global.trackerController.connect('query-error',
                                          Lang.bind(this, this._onQueryError));
 
+        Global.offsetController.connect('item-count-changed',
+                                        Lang.bind(this, this._onItemCountChanged));
+
         Global.documentManager.connect('active-changed',
                                        Lang.bind(this, this._onActiveItemChanged));
         Global.documentManager.connect('load-started',
@@ -284,6 +389,32 @@ const Embed = new Lang.Class({
         }
     },
 
+    _hideNoResultsPage: function() {
+        if (this._noResultsChangeId != 0) {
+            Global.changeMonitor.disconnect(this._noResultsChangeId);
+            this._noResultsChangeId = 0;
+        }
+
+        this._noResults.actor.lower_bottom();
+    },
+
+    _onItemCountChanged: function() {
+        let itemCount = Global.offsetController.getItemCount();
+
+        if (itemCount == 0) {
+            // also listen to changes-pending while in this mode
+            this._noResultsChangeId =
+                Global.changeMonitor.connect('changes-pending', Lang.bind(this,
+                    function() {
+                        this._hideNoResultsPage();
+                    }));
+
+            this._noResults.actor.raise_top();
+        } else {
+            this._hideNoResultsPage();
+        }
+    },
+
     _onQueryError: function(manager, message, exception) {
         this._setError(message, exception.message);
     },
@@ -305,14 +436,14 @@ const Embed = new Lang.Class({
                                              time: 0.20,
                                              transition: 'easeInQuad',
                                              onComplete: function() {
-                                                 this._background.lower_bottom();
+                                                 this._viewActor.set_child_below_sibling(this._background, null);
                                              },
                                              onCompleteScope: this });
     },
 
     _windowModeChangeFlash: function() {
         // fade from white when returning to the view anyway
-        this._background.raise_top();
+        this._viewActor.set_child_above_sibling(this._background, null);
         this._background.opacity = 255;
         this._moveOutBackground();
     },
