@@ -482,146 +482,6 @@ gd_create_collection_icon (gint base_size,
   return retval;
 }
 
-#define _BG_MIN_SIZE 20
-#define _EMBLEM_MIN_SIZE 8
-
-/**
- * gd_create_symbolic_icon:
- * @name:
- *
- * Returns: (transfer full):
- */
-GIcon *
-gd_create_symbolic_icon (const gchar *name,
-                         gint base_size)
-{
-  gchar *symbolic_name;
-  GIcon *icon, *retval = NULL;
-  cairo_surface_t *surface;
-  cairo_t *cr;
-  GtkStyleContext *style;
-  GtkWidgetPath *path;
-  GdkPixbuf *pixbuf;
-  GtkIconTheme *theme;
-  GtkIconInfo *info;
-  gint bg_size;
-  gint emblem_size;
-  gint total_size;
-
-  total_size = base_size / 2;
-  bg_size = MAX (total_size / 2, _BG_MIN_SIZE);
-  emblem_size = MAX (bg_size - 8, _EMBLEM_MIN_SIZE);
-
-  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, total_size, total_size);
-  cr = cairo_create (surface);
-
-  style = gtk_style_context_new ();
-
-  path = gtk_widget_path_new ();
-  gtk_widget_path_append_type (path, GTK_TYPE_ICON_VIEW);
-  gtk_style_context_set_path (style, path);
-  gtk_widget_path_unref (path);
-
-  gtk_style_context_add_class (style, "documents-icon-bg");
-
-  gtk_render_background (style, cr, (total_size - bg_size) / 2, (total_size - bg_size) / 2, bg_size, bg_size);
-
-  symbolic_name = g_strconcat (name, "-symbolic", NULL);
-  icon = g_themed_icon_new_with_default_fallbacks (symbolic_name);
-  g_free (symbolic_name);
-
-  theme = gtk_icon_theme_get_default();
-  info = gtk_icon_theme_lookup_by_gicon (theme, icon, emblem_size,
-                                         GTK_ICON_LOOKUP_FORCE_SIZE);
-  g_object_unref (icon);
-
-  if (info == NULL)
-    goto out;
-
-  pixbuf = gtk_icon_info_load_symbolic_for_context (info, style, NULL, NULL);
-  gtk_icon_info_free (info);
-
-  if (pixbuf == NULL)
-    goto out;
-
-  gtk_render_icon (style, cr, pixbuf, (total_size - emblem_size) / 2,  (total_size - emblem_size) / 2);
-  g_object_unref (pixbuf);
-
-  retval = G_ICON (gdk_pixbuf_get_from_surface (surface, 0, 0, total_size, total_size));
-
- out:
-  g_object_unref (style);
-  cairo_surface_destroy (surface);
-  cairo_destroy (cr);
-
-  return retval;
-}
-
-/* taken from gtk/gtktreeview.c */
-static void
-send_focus_change (GtkWidget *widget,
-                   GdkDevice *device,
-		   gboolean   in)
-{
-  GdkDeviceManager *device_manager;
-  GList *devices, *d;
-
-  device_manager = gdk_display_get_device_manager (gtk_widget_get_display (widget));
-  devices = gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_MASTER);
-  devices = g_list_concat (devices, gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_SLAVE));
-  devices = g_list_concat (devices, gdk_device_manager_list_devices (device_manager, GDK_DEVICE_TYPE_FLOATING));
-
-  for (d = devices; d; d = d->next)
-    {
-      GdkDevice *dev = d->data;
-      GdkEvent *fevent;
-      GdkWindow *window;
-
-      if (gdk_device_get_source (dev) != GDK_SOURCE_KEYBOARD)
-        continue;
-
-      window = gtk_widget_get_window (widget);
-
-      /* Skip non-master keyboards that haven't
-       * selected for events from this window
-       */
-      if (gdk_device_get_device_type (dev) != GDK_DEVICE_TYPE_MASTER &&
-          !gdk_window_get_device_events (window, dev))
-        continue;
-
-      fevent = gdk_event_new (GDK_FOCUS_CHANGE);
-
-      fevent->focus_change.type = GDK_FOCUS_CHANGE;
-      fevent->focus_change.window = g_object_ref (window);
-      fevent->focus_change.in = in;
-      gdk_event_set_device (fevent, device);
-
-      gtk_widget_send_focus_change (widget, fevent);
-
-      gdk_event_free (fevent);
-    }
-
-  g_list_free (devices);
-}
-
-void
-gd_entry_focus_hack (GtkWidget *entry,
-                     GdkDevice *device)
-{
-  GtkEntryClass *entry_class;
-  GtkWidgetClass *entry_parent_class;
-
-  /* Grab focus will select all the text.  We don't want that to happen, so we
-   * call the parent instance and bypass the selection change.  This is probably
-   * really non-kosher. */
-  entry_class = g_type_class_peek (GTK_TYPE_ENTRY);
-  entry_parent_class = g_type_class_peek_parent (entry_class);
-  (entry_parent_class->grab_focus) (entry);
-
-  /* send focus-in event */
-  send_focus_change (entry, device, TRUE);
-}
-
 /**
  * gd_create_variant_from_pixbuf:
  * @pixbuf:
