@@ -21,7 +21,7 @@
 
 const Global = imports.global;
 
-const Gd = imports.gi.Gd;
+const GdPrivate = imports.gi.GdPrivate;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Lang = imports.lang;
@@ -37,8 +37,8 @@ const QueryColumns = {
     IDENTIFIER: 7,
     RDFTYPE: 8,
     RESOURCE_URN: 9,
-    FAVORITE: 10,
-    SHARED: 11
+    SHARED: 10,
+    DATE_CREATED: 11
 };
 
 const QueryFlags = {
@@ -196,8 +196,8 @@ const QueryBuilder = new Lang.Class({
             'nao:identifier(?urn) ' + // identifier
             'rdf:type(?urn) ' + // type
             'nie:dataSource(?urn) ' + // resource URN
-            '( EXISTS { ?urn nao:hasTag nao:predefined-tag-favorite } ) ' + // favorite
             '( EXISTS { ?urn nco:contributor ?contributor FILTER ( ?contributor != ?creator ) } ) ' + // shared
+            'tracker:coalesce(nfo:fileCreated(?urn), nie:contentCreated(?urn)) ' + // date created
             whereSparql + tailSparql;
 
         return sparql;
@@ -254,7 +254,7 @@ const QueryBuilder = new Lang.Class({
 
     // bumps the mtime to current time for the given resource
     buildUpdateMtimeQuery: function(resource) {
-        let time = Gd.iso8601_from_timestamp(GLib.get_real_time() / GLib.USEC_PER_SEC);
+        let time = GdPrivate.iso8601_from_timestamp(GLib.get_real_time() / GLib.USEC_PER_SEC);
         let sparql = ('INSERT OR REPLACE { <%s> nie:contentLastModified \"%s\" }'
                      ).format(resource, time);
 
@@ -262,7 +262,7 @@ const QueryBuilder = new Lang.Class({
     },
 
     buildCreateCollectionQuery: function(name) {
-        let time = Gd.iso8601_from_timestamp(GLib.get_real_time() / GLib.USEC_PER_SEC);
+        let time = GdPrivate.iso8601_from_timestamp(GLib.get_real_time() / GLib.USEC_PER_SEC);
         let sparql = ('INSERT { _:res a nfo:DataContainer ; a nie:DataObject ; ' +
                       'nie:contentLastModified \"' + time + '\" ; ' +
                       'nie:title \"' + name + '\" ; ' +
